================
Building Plugins
================

Building a plugin in erin is very easy as you will see soon. However, before we start, we need a working bot to build plugins for.
If you haven't already, setup a bot by following :ref:`basic_usage`.

All builtin plugins are stored in the ``plugins`` directory found in the root folder of your project.

.. toctree::
   :maxdepth: 2

   Tutorials <tutorials/index.rst>
